package de.intevation.flys.artifacts.math.fitting;

import java.util.Collection;
import java.util.LinkedHashMap;
import java.util.Map;

public final class FunctionFactory
{
    private static FunctionFactory instance;

    private Map<String, Function> functions;

    private FunctionFactory() {
        functions = new LinkedHashMap<String, Function>();

        registerFunction(new Log());
        registerFunction(new Linear());
        registerFunction(new LogLinear());
        registerFunction(new Exp());
        registerFunction(new Quad());
        registerFunction(new Pow());
    }

    public static synchronized FunctionFactory getInstance() {
        if (instance == null) {
            instance = new FunctionFactory();
        }
        return instance;
    }

    public Function getFunction(String name) {
        return functions.get(name);
    }

    public void registerFunction(Function function) {
        functions.put(function.getName(), function);
    }

    public Collection<Function> getFunctions() {
        return functions.values();
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
